/********************************************************************************
** Form generated from reading UI file 'prefs_run_program_widget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef PREFS_RUN_PROGRAM_WIDGET_H
#define PREFS_RUN_PROGRAM_WIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_spin_box.h"

namespace mtx {
namespace gui {

class Ui_PrefsRunProgramWidget
{
public:
    QVBoxLayout *verticalLayout_6;
    QCheckBox *cbConfigurationActive;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *cbAfterJobSuccessful;
    QCheckBox *cbAfterJobWarnings;
    QCheckBox *cbAfterJobError;
    QCheckBox *cbAfterJobQueueStopped;
    QHBoxLayout *horizontalLayout;
    QPushButton *pbExecuteNow;
    QSpacerItem *horizontalSpacer;
    QLabel *lWhenToExecute;
    QLabel *lType;
    QComboBox *cbType;
    QLabel *label;
    QLineEdit *leName;
    QGroupBox *gbTypeSpecificSettings;
    QVBoxLayout *verticalLayout_3;
    QStackedWidget *typeWidgets;
    QWidget *emptyTypePage;
    QWidget *executeProgramTypePage;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lCommandLine;
    QLineEdit *leCommandLine;
    QPushButton *pbBrowseExecutable;
    QPushButton *pbAddVariable;
    QTextBrowser *tbUsageNotes;
    QWidget *playAudioFileTypePage;
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *leAudioFile;
    QPushButton *pbBrowseAudioFile;
    QLabel *label_2;
    mtx::gui::Util::BasicSpinBox *sbVolume;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *mtx__gui__PrefsRunProgramWidget)
    {
        if (mtx__gui__PrefsRunProgramWidget->objectName().isEmpty())
            mtx__gui__PrefsRunProgramWidget->setObjectName("mtx__gui__PrefsRunProgramWidget");
        mtx__gui__PrefsRunProgramWidget->resize(735, 450);
        mtx__gui__PrefsRunProgramWidget->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_6 = new QVBoxLayout(mtx__gui__PrefsRunProgramWidget);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(-1, -1, -1, 3);
        cbConfigurationActive = new QCheckBox(mtx__gui__PrefsRunProgramWidget);
        cbConfigurationActive->setObjectName("cbConfigurationActive");

        verticalLayout_6->addWidget(cbConfigurationActive);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        cbAfterJobSuccessful = new QCheckBox(mtx__gui__PrefsRunProgramWidget);
        cbAfterJobSuccessful->setObjectName("cbAfterJobSuccessful");

        verticalLayout_4->addWidget(cbAfterJobSuccessful);

        cbAfterJobWarnings = new QCheckBox(mtx__gui__PrefsRunProgramWidget);
        cbAfterJobWarnings->setObjectName("cbAfterJobWarnings");

        verticalLayout_4->addWidget(cbAfterJobWarnings);

        cbAfterJobError = new QCheckBox(mtx__gui__PrefsRunProgramWidget);
        cbAfterJobError->setObjectName("cbAfterJobError");

        verticalLayout_4->addWidget(cbAfterJobError);

        cbAfterJobQueueStopped = new QCheckBox(mtx__gui__PrefsRunProgramWidget);
        cbAfterJobQueueStopped->setObjectName("cbAfterJobQueueStopped");

        verticalLayout_4->addWidget(cbAfterJobQueueStopped);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        pbExecuteNow = new QPushButton(mtx__gui__PrefsRunProgramWidget);
        pbExecuteNow->setObjectName("pbExecuteNow");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("system-run")));
        pbExecuteNow->setIcon(icon);

        horizontalLayout->addWidget(pbExecuteNow);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_4->addLayout(horizontalLayout);


        gridLayout->addLayout(verticalLayout_4, 2, 1, 1, 1);

        lWhenToExecute = new QLabel(mtx__gui__PrefsRunProgramWidget);
        lWhenToExecute->setObjectName("lWhenToExecute");

        gridLayout->addWidget(lWhenToExecute, 2, 0, 1, 1, Qt::AlignTop);

        lType = new QLabel(mtx__gui__PrefsRunProgramWidget);
        lType->setObjectName("lType");

        gridLayout->addWidget(lType, 1, 0, 1, 1);

        cbType = new QComboBox(mtx__gui__PrefsRunProgramWidget);
        cbType->setObjectName("cbType");

        gridLayout->addWidget(cbType, 1, 1, 1, 1);

        label = new QLabel(mtx__gui__PrefsRunProgramWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        leName = new QLineEdit(mtx__gui__PrefsRunProgramWidget);
        leName->setObjectName("leName");
        leName->setClearButtonEnabled(true);

        gridLayout->addWidget(leName, 0, 1, 1, 1);


        verticalLayout_6->addLayout(gridLayout);

        gbTypeSpecificSettings = new QGroupBox(mtx__gui__PrefsRunProgramWidget);
        gbTypeSpecificSettings->setObjectName("gbTypeSpecificSettings");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(gbTypeSpecificSettings->sizePolicy().hasHeightForWidth());
        gbTypeSpecificSettings->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(gbTypeSpecificSettings);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        typeWidgets = new QStackedWidget(gbTypeSpecificSettings);
        typeWidgets->setObjectName("typeWidgets");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(typeWidgets->sizePolicy().hasHeightForWidth());
        typeWidgets->setSizePolicy(sizePolicy1);
        emptyTypePage = new QWidget();
        emptyTypePage->setObjectName("emptyTypePage");
        typeWidgets->addWidget(emptyTypePage);
        executeProgramTypePage = new QWidget();
        executeProgramTypePage->setObjectName("executeProgramTypePage");
        verticalLayout = new QVBoxLayout(executeProgramTypePage);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lCommandLine = new QLabel(executeProgramTypePage);
        lCommandLine->setObjectName("lCommandLine");

        horizontalLayout_3->addWidget(lCommandLine);

        leCommandLine = new QLineEdit(executeProgramTypePage);
        leCommandLine->setObjectName("leCommandLine");
        leCommandLine->setClearButtonEnabled(true);

        horizontalLayout_3->addWidget(leCommandLine);

        pbBrowseExecutable = new QPushButton(executeProgramTypePage);
        pbBrowseExecutable->setObjectName("pbBrowseExecutable");
        pbBrowseExecutable->setText(QString::fromUtf8(""));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("document-open")));
        pbBrowseExecutable->setIcon(icon1);

        horizontalLayout_3->addWidget(pbBrowseExecutable);

        pbAddVariable = new QPushButton(executeProgramTypePage);
        pbAddVariable->setObjectName("pbAddVariable");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-add")));
        pbAddVariable->setIcon(icon2);

        horizontalLayout_3->addWidget(pbAddVariable);


        verticalLayout->addLayout(horizontalLayout_3);

        tbUsageNotes = new QTextBrowser(executeProgramTypePage);
        tbUsageNotes->setObjectName("tbUsageNotes");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(1);
        sizePolicy2.setHeightForWidth(tbUsageNotes->sizePolicy().hasHeightForWidth());
        tbUsageNotes->setSizePolicy(sizePolicy2);
        tbUsageNotes->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p></body></html>"));

        verticalLayout->addWidget(tbUsageNotes);

        typeWidgets->addWidget(executeProgramTypePage);
        playAudioFileTypePage = new QWidget();
        playAudioFileTypePage->setObjectName("playAudioFileTypePage");
        verticalLayout_5 = new QVBoxLayout(playAudioFileTypePage);
        verticalLayout_5->setObjectName("verticalLayout_5");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(playAudioFileTypePage);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        leAudioFile = new QLineEdit(playAudioFileTypePage);
        leAudioFile->setObjectName("leAudioFile");
        leAudioFile->setClearButtonEnabled(true);

        horizontalLayout_2->addWidget(leAudioFile);

        pbBrowseAudioFile = new QPushButton(playAudioFileTypePage);
        pbBrowseAudioFile->setObjectName("pbBrowseAudioFile");
        pbBrowseAudioFile->setText(QString::fromUtf8(""));
        pbBrowseAudioFile->setIcon(icon1);

        horizontalLayout_2->addWidget(pbBrowseAudioFile);


        gridLayout_2->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        label_2 = new QLabel(playAudioFileTypePage);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        sbVolume = new mtx::gui::Util::BasicSpinBox(playAudioFileTypePage);
        sbVolume->setObjectName("sbVolume");
        sbVolume->setSuffix(QString::fromUtf8("%"));
        sbVolume->setMaximum(100);

        gridLayout_2->addWidget(sbVolume, 1, 1, 1, 1);


        verticalLayout_5->addLayout(gridLayout_2);

        verticalSpacer = new QSpacerItem(20, 153, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        typeWidgets->addWidget(playAudioFileTypePage);

        verticalLayout_3->addWidget(typeWidgets);


        verticalLayout_6->addWidget(gbTypeSpecificSettings);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_3);

#if QT_CONFIG(shortcut)
        lType->setBuddy(cbType);
        label->setBuddy(leName);
        lCommandLine->setBuddy(leCommandLine);
        label_3->setBuddy(leAudioFile);
        label_2->setBuddy(sbVolume);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(cbConfigurationActive, leName);
        QWidget::setTabOrder(leName, cbType);
        QWidget::setTabOrder(cbType, cbAfterJobSuccessful);
        QWidget::setTabOrder(cbAfterJobSuccessful, cbAfterJobWarnings);
        QWidget::setTabOrder(cbAfterJobWarnings, cbAfterJobError);
        QWidget::setTabOrder(cbAfterJobError, cbAfterJobQueueStopped);
        QWidget::setTabOrder(cbAfterJobQueueStopped, pbExecuteNow);
        QWidget::setTabOrder(pbExecuteNow, leCommandLine);
        QWidget::setTabOrder(leCommandLine, pbBrowseExecutable);
        QWidget::setTabOrder(pbBrowseExecutable, pbAddVariable);
        QWidget::setTabOrder(pbAddVariable, tbUsageNotes);
        QWidget::setTabOrder(tbUsageNotes, leAudioFile);
        QWidget::setTabOrder(leAudioFile, pbBrowseAudioFile);
        QWidget::setTabOrder(pbBrowseAudioFile, sbVolume);

        retranslateUi(mtx__gui__PrefsRunProgramWidget);

        typeWidgets->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(mtx__gui__PrefsRunProgramWidget);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__PrefsRunProgramWidget)
    {
        cbConfigurationActive->setText(QTR("C&onfiguration active", nullptr));
        cbAfterJobSuccessful->setText(QTR("After a job completes &successfully", nullptr));
        cbAfterJobWarnings->setText(QTR("After a job exits with &warnings", nullptr));
        cbAfterJobError->setText(QTR("After a job exits with an &error or the user aborts the job", nullptr));
        cbAfterJobQueueStopped->setText(QTR("After the job &queue has stopped", nullptr));
        pbExecuteNow->setText(QTR("E&xecute now", nullptr));
        lWhenToExecute->setText(QTR("When to execute:", nullptr));
        lType->setText(QTR("&Type:", nullptr));
        label->setText(QTR("&Name:", nullptr));
        gbTypeSpecificSettings->setTitle(QTR("Type-specific settings", nullptr));
        lCommandLine->setText(QTR("&Command line:", nullptr));
        pbAddVariable->setText(QTR("Add &variable", nullptr));
        label_3->setText(QTR("A&udio file:", nullptr));
        label_2->setText(QTR("&Volume:", nullptr));
        (void)mtx__gui__PrefsRunProgramWidget;
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class PrefsRunProgramWidget: public Ui_PrefsRunProgramWidget {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // PREFS_RUN_PROGRAM_WIDGET_H
